@@ -167,7 +167,7 @@ class sqlobj(object):
 				current_cursor = self.connection.cursor()
 				current_cursor.execute("SELECT name FROM sqlite_master WHERE type='table';")
 				for name in current_cursor.fetchall():
-					self.dataframes[name[0]] = pd.read_sql_query("SELECT * FROM {0}".format(name[0]), self.connection)
+					self.dataframes[name[0]] = pd.read_sql_query("""SELECT * FROM "{0}";""".format(name[0]), self.connection)
 				current_cursor = None
 
 	def __enter__(self):
@@ -217,7 +217,7 @@ class sqlobj(object):
 
 		output = pd.DataFrame()
 		if just_enter:
-			output = pd.read_sql_query("SELECT * FROM {0}".format(table_name), self.connection)
+			output = pd.read_sql_query("""SELECT * FROM "{0}";""".format(table_name), self.connection)
 		else:
 			output = self.dataframes[table_name]
 
@@ -299,7 +299,7 @@ class sqlobj(object):
 			current_cursor = self.connection.cursor()
 			current_cursor.execute("SELECT name FROM sqlite_master WHERE type='table';")
 			for name in current_cursor.fetchall():
-				tables  += [pd.read_sql_query("SELECT * FROM {0}".format(name[0]), self.connection)]
+				tables  += [pd.read_sql_query("""SELECT * FROM "{0}";""".format(name[0]), self.connection)]
 			current_cursor = None
 		else:
 			tables = self.dataframes.values()
@@ -321,7 +321,7 @@ class sqlobj(object):
 			current_cursor = self.connection.cursor()
 			current_cursor.execute("SELECT name FROM sqlite_master WHERE type='table';")
 			for name in current_cursor.fetchall():
-				tables[name[0]] =  [pd.read_sql_query("SELECT * FROM {0}".format(name[0]), self.connection)]
+				tables[name[0]] =  [pd.read_sql_query("""SELECT * FROM "{0}";""".format(name[0]), self.connection)]
 			current_cursor = None
 		else:
 			tables = self.dataframes.values()
@@ -357,7 +357,7 @@ class sqlobj(object):
 
 			if just_enter:
 				current_cursor = self.connection.cursor()
-				current_cursor.execute("DROP table IF EXISTS {0};".format(table_name))
+				current_cursor.execute("""DROP table IF EXISTS "{0}";""".format(table_name))
 				current_cursor = None
 			else:
 				try:
